% ECON245
% Armington Model with Worker Mobility
% Outer Equilibrium Loop Solver


function [w,L] = eqm(p,tau)

% Initialize
L = ones(p.S,1);
L = p.Lbar.*(L./sum(L));

err = 1;
iter = 0;

while err>p.tol_1

% Solve Labor Market equilibrium given L
[~,w] = trade_eq(p,L,tau);

% Constructing Prices 
price  = (w./p.A).*tau;
price_index = sum(price.^(1-p.sigma),1).^(1/(1-p.sigma));
price_index = price_index';

% Constructing Real Income
real_income = p.U.*w./price_index;
avg_real_income = sum(real_income.*L./sum(L));

% Compute Population Stock Implied by Labor Market Equilibrium
if (p.mobility == 0)
    L_new = L.*(real_income./avg_real_income);
    L_new = p.Lbar.*L_new./sum(L_new);
elseif (p.mobility == 1)
    L_new = real_income.^p.theta;
    L_new = p.Lbar.*L_new./sum(L_new);
end 

% Compute Error 
err = max(abs(log(L./L_new)));

% Update Local Population
L = p.tune_1*L_new+(1-p.tune_1).*L;

% Iteration counter
iter = iter +1;

% Print Error 
fprintf('Outer Loop: Iteration %.4f, Error %.4f \n',iter, err)

end

end