% ECON245
% Armington Model with Worker Mobility
% Inner Equilibrium Loop Solver



function [lambda,w] = trade_eq(p,L,tau)

% Initialize 
w = ones(p.S,1);
err = 1;
iter = 0;

while err>p.tol_2
  
% Price of local varieties in each destination
price  = (w./p.A).*tau;

% Matrix of trade shares
lambda = price.^(1-p.sigma);
lambda = lambda./repmat(sum(lambda,1),p.S,1);

% Updating wages using goods market clearing
w_new = (1./L).*sum(lambda.*repmat((w.*L)',p.S,1),2);

% Enforcing normalization
w_new = w_new./w_new(1,1);

% Convergence criterion
err = max(abs(log(w./w_new)));

% Updating wages with tuning factor theta
w = p.tune_2*w_new+(1-p.tune_2)*w;

% Iteration counter
iter = iter +1;

% Print Error 
fprintf('Inner Loop: Iteration %.4f, Error %.4f \n',iter, err)

end

end


